aboutsummaryrefslogtreecommitdiffstats
path: root/LUFA/Drivers/USB/Class/Host/RNDISClassHost.h
diff options
context:
space:
mode:
authorDean Camera <dean@fourwalledcubicle.com>2011-11-24 01:24:01 +0000
committerDean Camera <dean@fourwalledcubicle.com>2011-11-24 01:24:01 +0000
commit8b5aa616013811faf53fb5c1f2fdb819dd671b36 (patch)
treea80c32e89a847b46e046f70907ff2013c8516647 /LUFA/Drivers/USB/Class/Host/RNDISClassHost.h
parent075538abb9af8a31fa8239ecfda592b968cd53d8 (diff)
downloadlufa-8b5aa616013811faf53fb5c1f2fdb819dd671b36.tar.gz
lufa-8b5aa616013811faf53fb5c1f2fdb819dd671b36.tar.bz2
lufa-8b5aa616013811faf53fb5c1f2fdb819dd671b36.zip
Add new Android Open Accessory class driver to the library core and add a new Android Open Accessory Host ClassDriver demo.
Diffstat (limited to 'LUFA/Drivers/USB/Class/Host/RNDISClassHost.h')
-rw-r--r--LUFA/Drivers/USB/Class/Host/RNDISClassHost.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/LUFA/Drivers/USB/Class/Host/RNDISClassHost.h b/LUFA/Drivers/USB/Class/Host/RNDISClassHost.h
index 7b0acfb5c..de66c86b2 100644
--- a/LUFA/Drivers/USB/Class/Host/RNDISClassHost.h
+++ b/LUFA/Drivers/USB/Class/Host/RNDISClassHost.h
@@ -42,7 +42,7 @@
*
* \section Sec_Dependencies Module Source Dependencies
* The following files must be built with any user project that uses this module:
- * - LUFA/Drivers/USB/Class/Host/RNDIS.c <i>(Makefile source module name: LUFA_SRC_USBCLASS)</i>
+ * - LUFA/Drivers/USB/Class/Host/RNDISClassHost.c <i>(Makefile source module name: LUFA_SRC_USBCLASS)</i>
*
* \section Sec_ModDescription Module Description
* Host Mode USB Class driver framework interface, for the Microsoft RNDIS Ethernet
@@ -131,15 +131,15 @@
* This should be called once after the stack has enumerated the attached device, while the host state machine is in
* the Addressed state.
*
* \param[in,out] RNDISInterfaceInfo Pointer to a structure containing an RNDIS Class host configuration and state.
* \param[in] ConfigDescriptorSize Length of the attached device's Configuration Descriptor.
* \param[in] DeviceConfigDescriptor Pointer to a buffer containing the attached device's Configuration Descriptor.
*
* \return A value from the \ref RNDIS_Host_EnumerationFailure_ErrorCodes_t enum.
*/
uint8_t RNDIS_Host_ConfigurePipes(USB_ClassInfo_RNDIS_Host_t* const RNDISInterfaceInfo,
uint16_t ConfigDescriptorSize,
- void* DeviceConfigDescriptor) ATTR_NON_NULL_PTR_ARG(1) ATTR_NON_NULL_PTR_ARG(3);
+ void* ConfigDescriptorData) ATTR_NON_NULL_PTR_ARG(1) ATTR_NON_NULL_PTR_ARG(3);
/** Sends a RNDIS KEEPALIVE command to the device, to ensure that it does not enter standby mode after periods
* of long inactivity.
@@ -131,15 +131,15 @@
* the Addressed state.
*
- * \param[in,out] RNDISInterfaceInfo Pointer to a structure containing an RNDIS Class host configuration and state.
- * \param[in] ConfigDescriptorSize Length of the attached device's Configuration Descriptor.
- * \param[in] DeviceConfigDescriptor Pointer to a buffer containing the attached device's Configuration Descriptor.
+ * \param[in,out] RNDISInterfaceInfo Pointer to a structure containing an RNDIS Class host configuration and state.
+ * \param[in] ConfigDescriptorSize Length of the attached device's Configuration Descriptor.
+ * \param[in] ConfigDescriptorData Pointer to a buffer containing the attached device's Configuration Descriptor.
*
* \return A value from the \ref RNDIS_Host_EnumerationFailure_ErrorCodes_t enum.